@@ -28,7 +28,6 @@
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
-#include "xf86PciInfo.h"
 #include "xf86Pci.h"
 
 #include "vgaHW.h"
@@ -108,6 +107,14 @@ TridentFindMode(int xres, int yres, int depth)
     biosMode *mode;
 
     switch (depth) {
+    case 1:
+	size = sizeof(bios1) / sizeof(biosMode);
+	mode = bios1;
+	break;
+    case 4:
+	size = sizeof(bios4) / sizeof(biosMode);
+	mode = bios4;
+	break;
     case 8:
 	size = sizeof(bios8) / sizeof(biosMode);
 	mode = bios8;
@@ -1118,7 +1125,7 @@ TridentLoadCursorImage(
 static Bool 
 TridentUseHWCursor(ScreenPtr pScreen, CursorPtr pCurs)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     TRIDENTPtr pTrident = TRIDENTPTR(pScrn);
     
     if (pTrident->MUX && pScrn->bitsPerPixel == 8) return FALSE;
@@ -1135,7 +1142,7 @@ TridentUseHWCursor(ScreenPtr pScreen, CursorPtr pCurs)
 Bool 
 TridentHWCursorInit(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     TRIDENTPtr pTrident = TRIDENTPTR(pScrn);
     xf86CursorInfoPtr infoPtr;
     FBAreaPtr          fbarea;
@@ -1252,7 +1259,7 @@ void TridentSetOverscan(
 void TridentLoadPalette(
     ScrnInfoPtr pScrn, 
     int numColors, 
-    int *indicies,
+    int *indices,
     LOCO *colors,
     VisualPtr pVisual
 ){
@@ -1260,7 +1267,7 @@ void TridentLoadPalette(
     TRIDENTPtr pTrident = TRIDENTPTR(pScrn);
     int i, index;
     for(i = 0; i < numColors; i++) {
-	index = indicies[i];
+	index = indices[i];
     	OUTB(0x3C6, 0xFF);
 	DACDelay(hwp);
         OUTB(0x3c8, index);
